package com.cweb.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.RedisUtil;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.config.HuiLianTongUnionCardConfig;
import com.hai.entity.HighUserCard;
import com.hai.enum_type.UserCardType;
import com.hai.model.HighUserModel;
import com.hai.model.ResponseData;
import com.hai.service.HighUserCardService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Objects;

@Controller
@RequestMapping(value = "/highUserCard")
@Api(value = "订单接口")
public class HighUserCardController {

    private static Logger log = LoggerFactory.getLogger(HighUserCardController.class);

    @Resource
    private UserCenter userCenter;

    @Resource
    private HighUserCardService highUserCardService;

    @Resource
    private RedisUtil redisUtil;


    @RequestMapping(value = "/getUserCardList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取用户卡号列表")
    public ResponseData getUserCardList(@RequestParam(name = "type", required = false) Integer type, HttpServletRequest request) {
        try {
            // 用户
            SessionObject sessionObject = userCenter.getSessionObject(request);
            HighUserModel userInfoModel = (HighUserModel) sessionObject.getObject();
            return ResponseMsgUtil.success(highUserCardService.getListByUser(userInfoModel.getHighUser().getId(),type));
        } catch (Exception e) {
            log.error("HighUserCardController --> getUserCardList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/bindHuiLianTongCard", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "绑定汇联通工会卡")
    public ResponseData bindHuiLianTongCard(@RequestBody JSONObject body, HttpServletRequest request) {
        try {
            if (body == null || StringUtils.isBlank(body.getString("cardNo"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            // 用户
            SessionObject sessionObject = userCenter.getSessionObject(request);
            HighUserModel userInfoModel = (HighUserModel) sessionObject.getObject();

            if (highUserCardService.getDetailByUserCardNo(userInfoModel.getHighUser().getId(), body.getString("cardNo")) == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "已绑定此卡，请勿重复绑定");
            }

            HighUserCard userCard = new HighUserCard();
            userCard.setUserId(userInfoModel.getHighUser().getId());
            userCard.setCardNo(body.getString("cardNo"));
            userCard.setType(UserCardType.type1.getType());
            highUserCardService.editCard(userCard);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighUserCardController --> bindHuiLianTongCard() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getHuiLianTongCardByPhone", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "根据手机号获取汇联通工会卡列表")
    public ResponseData getHuiLianTongCardByPhone(@RequestParam(name = "phone", required = true) String phone,
                                                  @RequestParam(name = "smsCode", required = true) String smsCode,
                                                  HttpServletRequest request) {
        try {
            // 用户
            SessionObject sessionObject = userCenter.getSessionObject(request);
            HighUserModel userInfoModel = (HighUserModel) sessionObject.getObject();

            // 获取手机号验证码
            String phoneSmsCode = (String) redisUtil.get(phone);

            // 验证码校验
            if (StringUtils.isNotBlank(phoneSmsCode) && Objects.equals(phoneSmsCode,smsCode)) {
                // 验证码校验成功
                // 根据手机号查询卡号
                JSONObject jsonObject = HuiLianTongUnionCardConfig.queryCardByMobile(phone);
                if(jsonObject.getString("respCode").equals("0000") && jsonObject.getString("respMessage").equals("ok")) {
                    JSONObject dataObject = HuiLianTongUnionCardConfig.resolveResponse(jsonObject.getString("data"));
                    JSONArray cards = dataObject.getJSONArray("cards");
                    for (Object cardObject : cards) {
                        JSONObject card = (JSONObject)cardObject;
                        if (highUserCardService.getDetailByUserCardNo(userInfoModel.getHighUser().getId(), card.getString("cardNo")) != null) {
                            card.put("bindStatus", true);
                        } else {
                            card.put("bindStatus", false);
                        }
                    }
                    redisUtil.del(phone);
                    return ResponseMsgUtil.success(cards);
                } else {
                    System.out.println(jsonObject);
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "查询失败");
                }
            }
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "验证码错误");
        } catch (Exception e) {
            log.error("HighUserCardController --> getHuiLianTongCardByPhone() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


}
